/**
 * Created by WebStorm.
 * User: martin
 * Date: 18/05/2020
 * Time: 14:00

 */
import { writable, get } from 'svelte/store';

import axios from 'redaxios';

const baseUrl = (__ENV__ === 'production') ? (`${location.protocol }//${ location.hostname}`) : 'http://localhost:3000';
// const baseUrl = 'http://localhost:3000';
const urls = {
  'jobs': baseUrl.concat('/jobs'),
  'apply': baseUrl.concat('/apply'),
  'readall' : baseUrl.concat('/readall'),
  'kill' : baseUrl.concat('/kill'),
  'upvote' : baseUrl.concat('/vote/up'),
  'downvote' : baseUrl.concat('/vote/down')
};

const JobList = writable([]);
const JobDetails = writable({});

const actions = {
  getJobList() {
    axios.get(urls.jobs).then((d) => {
      // console.log('>> retrieved', d);
      const data = JSON.parse(d.data);
      
      JobList.set(data);
    }).catch((err) => {
      console.error('getJobList', err);
    });
  },
  
  loadJobDetail(id) {
    console.log(`loadJobDetail: ${id}`);
    if (id) {
      const u = `${urls.jobs}/${id}`;
      axios.get(u).then((d) => {
        const data = JSON.parse(d.data);

        JobDetails.set(data);
      }).catch((err) => {
        console.error('loadJobDetail', err);
      });
    }
  },

  async touchJob(id) {
    console.log(`touchJob: ${id}`);
    if (id) {
      const u = `${urls.jobs}/${id}`;
      await axios.put(u).then((d) => {
        if (d.status !== 200) 
          console.error(d);
      }).catch((err) => {
        console.error('touchJob', err);
      });

      JobList.update((data) => {
        data.map((v) => {
          if (v._id === id) {
            v.read = new Date().getTime();

            return v;
          }
        });

        return data;
      });
    }
  },

  async appliedJob(id) {
    console.log(`touchJob: ${id}`);

    const now = new Date().getTime();

    // JobDetails

    if (id) {
      console.log('Applying..');
      const u = `${urls.apply}/${id}`;
      await axios.put(u).then((d) => {
        if (d.status !== 200)
          console.error(d);
      }).catch((err) => {
        console.error('appliedJob', err);
      });

      const _id = parseInt(id, 10);

      JobList.update((data) => {
        data.map((v) => {
          if (v._id === _id) {
            v.a = now;

            return v;
          }
        });

        return data;
      });

      JobDetails.update((v) => {
        v.a = now;

        return v;
      });
    }
  },

  async markAllRead() {
    console.log('>> markAllRead');

    const u = `${urls.readall}`;
    await axios.put(u).then((d) => {
      if (d.status !== 200)
        console.error(d);
    }).catch((err) => {
      console.error('markAllRead', err);
    });

    this.getJobList();
  },

  killWord(word) {
    console.log(`>> killword:${word}`);

    const u = `${urls.kill}/${word}`;
    axios.put(u).then((d) => {
      if (d.status !== 200)
        console.error(d);
    }).catch((err) => {
      console.error('killword', err);
    });
  },

  upVote(id) {
    console.log(`>> upvote:${id}`);

    const u = `${urls.upvote}/${id}`;
    axios.put(u).then((d) => {
      if (d.status !== 200)
        console.error(d);
    }).catch((err) => {
      console.error('upvote', err);
    });
  },

  downVote(id) {
    console.log(`>> downvote:${id}`);

    const u = `${urls.downvote}/${id}`;
    axios.put(u).then((d) => {
      if (d.status !== 200)
        console.error(d);
    }).catch((err) => {
      console.error('downvote', err);
    });
  }


};

export { JobList, JobDetails, actions };
